@@ -23,6 +23,7 @@ import prasopes.zcetools as zce
 import prasopes.docks as docks
 import prasopes.datasets as datasets
 import prasopes.mobtools_gui as mtg
+import prasopes.drlmobtools_gui as mdrlgui
 import prasopes.tangoicons
 import sys
 import logging
@@ -247,6 +248,18 @@ def key_pressed(event, augCanvas, config, update):
         gt.shift_times(event, augCanvas)
 
 
+def updatehelp(parent):
+    """constructs window with "update" info"""
+    QtWidgets.QMessageBox.information(
+            parent, "Updating Prasopes",
+            "How to update prasopes (windows):\n"
+            "1. run cmd (as administrator)\n"
+            "2. type: \"pip install prasopes -U\"\n"
+            "3. Check versionin help->about\n\n"
+            "Linux:\n"
+            "probably not in repos yet, go for git..")
+
+
 def about(parent):
     """constructs window with "about" info"""
     rawparver = rawautoparams.__version__ if autoparams else\
@@ -297,6 +310,7 @@ def main():
     p_logger.addHandler(barHandler)
     zce_logger.addHandler(barHandler)
     params_logger.addHandler(barHandler)
+    ds_logger.addHandler(barHandler)
     barHandler.setLevel("DEBUG")
 
     main_window = QtWidgets.QMainWindow(windowTitle="Prasopes")
@@ -347,13 +361,20 @@ def main():
     drlact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_D)
     drlact.triggered.connect(lambda: drlgui.main_window(
         main_window, augCanvas, update))
-    tofact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
+    mobact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
         "applications-utilities"), "&MOB...", None)
-    tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_M)
-    tofact.triggered.connect(lambda: mtg.main_window(
+    mobact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_M)
+    mobact.triggered.connect(lambda: mtg.main_window(
+        main_window, augCanvas, update))
+    drlmobact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
+        "applications-utilities"), "DR&LMOB...", None)
+    drlmobact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_L)
+    drlmobact.triggered.connect(lambda: mdrlgui.main_window(
         main_window, augCanvas, update))
     aboutact = QtWidgets.QAction("&About Prasopes", None)
     aboutact.triggered.connect(lambda: about(main_window))
+    updatehelpact = QtWidgets.QAction("&Update Prasopes", None)
+    updatehelpact.triggered.connect(lambda: updatehelp(main_window))
     autozoomy = QtWidgets.QAction(QtGui.QIcon.fromTheme(
         "zoom-original"), "Auto Zoom Y", None, checkable=True,
         checked=config.value("view/autozoomy", type=bool))
@@ -404,7 +425,8 @@ def main():
     main_window.menuBar().addMenu(tools_menu)
     tools_menu.addAction(zceact)
     tools_menu.addAction(drlact)
-    tools_menu.addAction(tofact)
+    tools_menu.addAction(mobact)
+    tools_menu.addAction(drlmobact)
     tools_menu.addSeparator()
     view_menu = QtWidgets.QMenu('&View', main_window)
     [view_menu.addAction(i.action) for i in
@@ -415,6 +437,7 @@ def main():
     main_window.menuBar().addMenu(view_menu)
     help_menu = QtWidgets.QMenu('&Help', main_window)
     main_window.menuBar().addMenu(help_menu)
+    help_menu.addAction(updatehelpact)
     help_menu.addAction(aboutact)
 
     main_window.setCentralWidget(augCanvas)
@@ -433,7 +456,8 @@ def main():
     toolBar.addSeparator()
     toolBar.addAction(zceact)
     toolBar.addAction(drlact)
-    toolBar.addAction(tofact)
+    toolBar.addAction(mobact)
+    toolBar.addAction(drlmobact)
     toolBar.addSeparator()
     toolBar.addAction(autozoomy)
 
