@@ -15,8 +15,24 @@ def argsubselect(array, minimum, maximum):
     return args
 
 
+def argsubselect_2d(array1, min1, max1, array2, min2, max2):
+    """finds arguments which fits into boundary conditions,
+    if there is no fit, return nearest argument"""
+    bounds1 = sorted([min1, max1])
+    bounds2 = sorted([min2, max2])
+    args = np.where((array1 >= bounds1[0]) & (array1 <= bounds1[1]) &
+                    (array2 >= bounds2[0]) & (array2 <= bounds2[1]))[0]
+    if len(args) == 0:
+        # aver = (min1+max1)/2
+        # args = np.array([(np.abs(array - aver)).argmin()])
+        # TODO: FIXME!! THIS IS REALLY BAD!!
+        args = [0]
+    return args
+
+
 def specttostr(augCanvas, delim=" ", names=["mass", "ion_count"],
                units=["m/z", ""], description=""):
+    """converts spectrum to string"""
     lines = augCanvas.get_lines()
     formnames = delim.join([delim.join(names) for i in range(len(lines))])
     formunits = (delim).join([delim.join(units) for i in range(len(lines))])
@@ -35,6 +51,7 @@ def specttostr(augCanvas, delim=" ", names=["mass", "ion_count"],
 
 
 def clip_spectstr(augCanvas):
+    """clip converted spectrum to string"""
     description = ("{}_{:.4}-{:.4}_minutes_of_the_aquisition".format(
                    os.path.basename(augCanvas.ds.filename),
                    augCanvas.ds.mintime, augCanvas.ds.maxtime))
@@ -45,6 +62,7 @@ def clip_spectstr(augCanvas):
 
 
 def clip_tablestr(augCanvas):
+    """clip values from table"""
     pairs = [" ".join((augCanvas.paramstable.item(row, 1).text(),
                        augCanvas.paramstable.item(row, 2).text()))
              for row in range(augCanvas.paramstable.rowCount())
@@ -66,5 +84,4 @@ def table(labels, minsizex=600, minsizey=0):
         table.horizontalHeader().setSectionResizeMode(
             n, QtWidgets.QHeaderView.Stretch)
     table.setMinimumSize(minsizex, minsizey)
-
     return table
