@@ -96,10 +96,9 @@ def treeDockWidget(actionname, cfval, update, loadfnc, parent,
     dirview.setModel(fileModel)
 
     sortorder = QtWidgets.QComboBox()
-    sortorder.addItems(("name","time"))
-    sortorder.currentIndexChanged.connect(lambda index:
-            fileModel.sort(index and 3, 1))
-
+    sortorder.addItems(("name", "time"))
+    sortorder.currentIndexChanged.connect(
+        lambda index: fileModel.sort(index and 3, 1))
 
     orderlayout = QtWidgets.QHBoxLayout()
     orderlayout.addStretch(1)
