@@ -42,7 +42,7 @@ def update_profile(pt, row, dataset):
     spectrum = pt.cellWidget(row, 3).figure.get_axes()[0]
     spectrum.clear()
     limits = []
-    spectra = dataset.get_spectra(-np.inf, np.inf)
+    spectra = dataset.fullspectra
     for i, spectxy in enumerate(spectra):
         massargs = drl.get_subargs(pt, row, spectxy[0], 1, 2)
         spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
